# -*- coding: utf-8 -*-
"""
Created on 2020-04-13, 2020-05-06, 2020-12-10
Azimuth and elevation of any fixstar, defined by right-ascension and declination at given date
@author: Christian Monstein
"""
#------------------------------------------------------------------------------

import ephem
import numpy as np
from matplotlib import pyplot as plt
import math
import os

#------------------------------------------------------------------------------
# Date to be chosen by the user
year  = 2023
month =  10
day   = 14
name = 'Eclipse Hondo Texas'
#------------------------------------------------------------------------------
# Location parameter for Bleien

MyHome = ephem.Observer()
MyHome.lon      = '-99.14142'  # east +°
MyHome.lat      = '29.34746'  # north +°
MyHome.elev     = 493         # altitude in m asl
MyHome.temp     = 25          # °C
MyHome.pressure = 900         # mbar

#------------------------------------------------------------------------------

AZI = []
ELE = []
HM  = []
hh  = []

plt.figure()
plt.plot(AZI,ELE,'.b')
plt.title("{} on {:02d}-{:02d}-{:04d}".format(name,day,month,year))
plt.xlabel('Azimuth [°]')
plt.ylabel('Elevation [°]')
plt.xticks(np.arange(0, 360+1, 30.0))
plt.xlim(0,360)
plt.ylim(0,90)
plt.text(330,85,'Sun',color='r')
plt.text(330,80,'Moon',color='b')
for h in range(0,len(hh),3):
    if ((AZI[h]> 0) and  (AZI[h]<360) and (ELE[h]>0) and (ELE[h]<90)):
        plt.text(AZI[h],ELE[h],hh[h])
        
sun = ephem.Sun()
moon = ephem.Moon()

for h in range(0,24):
    for m in range(0,60,10):
        #dt = datetime.datetime.now()
        MyHome.date = '{:4d}/{:02d}/{:02d} {:02d}:{:02d}:{:02d}'.format(
                year,month,day,h,m,0)
        sun.compute(MyHome)
        moon.compute(MyHome)
        Sazi = math.degrees(sun.az)
        Sele = math.degrees(sun.alt)
        Mazi = math.degrees(moon.az)
        Mele = math.degrees(moon.alt)
        plt.plot(Sazi,Sele,'or')
        plt.plot(Mazi,Mele,'.b')
        #print("Sun data: Azimuth   =%6.2f  Elevation   =%6.2f" % (azi-180.0,ele)) 
    if ((h%1)==0):
        if ((Sazi> 0) and  (Sazi<360) and (Sele>0) and (Sele<90)):
            plt.text(Sazi,Sele,h)

plotfilename = '{:4d}-{:02d}-{:02d}_'.format(year,month,day) + name
plt.savefig(plotfilename)
plt.show()

#------------------------------------------------------------------------------
